@@ -44,10 +44,12 @@ OC.L10N.register(
     "Error" : "შეცდომა",
     "Blocked" : "დაბლოკილია",
     "Expired" : "გაუქმდა",
+    "Never" : "არასდროს",
     "Language" : "ენა",
     "Country" : "ქვეყანა",
     "Status" : "სტატუსი",
     "Created at" : "შეიქმნა",
+    "Yes" : "დიახ",
     "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
     "Shared secret" : "გაზიარებული საიდუმლო",
     "STUN servers" : "STUN სერვერები",
@@ -64,11 +66,13 @@ OC.L10N.register(
     "Save" : "შენახვა",
     "No results" : "შედეგები არაა",
     "Done" : "დასრულდა",
+    "Grid view" : "ბადისებური ხედი",
     "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
     "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
     "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
     "Copy link" : "ბმულის კოპირება",
     "Mute audio" : "ხმის ჩახშობა",
+    "None" : "არც ერთი",
     "Disable video" : "ვიდეოს გათიშვა",
     "Enable video" : "ვიდეოს ამოქმედება",
     "You" : "თქვენ",
@@ -80,7 +84,6 @@ OC.L10N.register(
     "Choose" : "აირჩიეთ",
     "Restricted" : "აკრძალული",
     "Personal" : "პირადი",
-    "Yes" : "დიახ",
     "Password protection" : "პაროლით თავდაცვა",
     "Set a password" : "პაროლის დაყენება",
     "Edit" : "შეცვლა",
@@ -92,21 +95,17 @@ OC.L10N.register(
     "Mark as unread" : "წაუკითხავად მონიშვნა",
     "Remove from favorites" : "რჩეულებიდან ამოშლა",
     "Add to favorites" : "რჩეულებში დამატება",
+    "Home" : "სახლი",
     "Users" : "მომხმარებლები",
     "Groups" : "ჯგუფები",
-    "None" : "არც ერთი",
     "Devices" : "მოწყობილობები",
     "Upload" : "ატვირთვა",
     "Files" : "ფაილები",
-    "Message sent" : "წერილი გაგზავნილია",
     "Reply" : "პასუხი",
     "Translate" : "გადათარგმნეთ",
     "Dismiss" : "დათხოვნა",
+    "Message sent" : "წერილი გაგზავნილია",
     "Contact" : "კონტაქტი",
-    "Today" : "დღეს",
-    "Yesterday" : "გუშინ",
-    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Create new poll" : "ახალი გამოკითხვის შექმნა",
     "Send" : "გაგზავნა",
     "Create poll" : "გამოკითხვის შექმნა",
@@ -122,17 +121,15 @@ OC.L10N.register(
     "Privacy" : "კონფიდენციალურობა",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Search" : "ძიება",
+    "More actions" : "მეტი ქმედება",
     "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
     "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
     "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
-    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
     "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
     "Show your screen" : "თქვენი ეკრანის ჩვენება",
     "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
-    "Grid view" : "ბადისებური ხედი",
     "Submit" : "გაგზავნა",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "User" : "მომხმარებელი",
     "Password" : "პაროლი",
     "API token" : "API ტოკენი",
@@ -142,9 +139,9 @@ OC.L10N.register(
     "Polls" : "გამოკითხვები",
     "Audio" : "აუდიო",
     "Other" : "სხვა",
+    "Default" : "საწყისი",
     "Group" : "ჯგუფი",
     "Please reload the page." : "გთხოვთ გადატვირთოთ გვერდი.",
-    "Default" : "საწყისი",
     "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
     "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
     "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
@@ -156,6 +153,11 @@ OC.L10N.register(
     "__language_name__" : "ქართული",
     "Tasks" : "დავალებები",
     "Notes" : "ჩანაწერები",
-    "Close" : "დახურვა"
+    "Today" : "დღეს",
+    "Yesterday" : "გუშინ",
+    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
+    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
+    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი."
 },
 "nplurals=2; plural=(n!=1);");
