@@ -90,10 +90,10 @@ OC.L10N.register(
     "Groups" : "Grupper",
     "Upload" : "Last opp",
     "Files" : "Filer",
-    "Message sent" : "Melding sendt",
     "Reply" : "Svare",
     "Reply privately" : "Svar privat",
     "Dismiss" : "Forkast",
+    "Message sent" : "Melding sendt",
     "Contact" : "Kontakt",
     "Add participants" : "Legg til deltakarar",
     "Send message" : "Send melding",
@@ -129,7 +129,6 @@ OC.L10N.register(
     "Tasks" : "Oppgåver",
     "Today" : "I dag",
     "Yesterday" : "i går",
-    "_%n day ago_::_%n days ago_" : ["%n dag sidan","%n dagar sidan"],
-    "Close" : "Lukk"
+    "_%n day ago_::_%n days ago_" : ["%n dag sidan","%n dagar sidan"]
 },
 "nplurals=2; plural=(n != 1);");
