@@ -250,10 +250,13 @@ OC.L10N.register(
     "Error" : "Erro",
     "Blocked" : "Bloqueado",
     "Expired" : "Expirado",
+    "Never" : "Nunca",
     "Language" : "Idioma",
     "Country" : "País",
     "Status" : "Estado",
     "Created at" : "Criado em",
+    "Yes" : "Sim",
+    "No" : "Não",
     "Downloading …" : "A transferir…",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Shared secret" : "Segredo partilhado",
@@ -295,8 +298,6 @@ OC.L10N.register(
     "Restricted" : "Restrito",
     "Personal" : "Pessoal",
     "Leave conversation" : "Sair da conversação",
-    "No" : "Não",
-    "Yes" : "Sim",
     "Delete conversation" : "Eliminar conversação",
     "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
     "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
@@ -329,10 +330,6 @@ OC.L10N.register(
     "Translate" : "Traduzir",
     "Dismiss" : "Dispensar",
     "Contact" : "Contacto",
-    "Today" : "Hoje",
-    "Yesterday" : "Ontem",
-    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Sem mensagens",
     "Create a new group conversation" : "Criar nova conversa de grupo",
     "Send message" : "Enviar mensagem",
@@ -361,18 +358,15 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Search" : "Pesquisa sobre",
     "More actions" : "Mais ações",
-    "Default" : "Predefinida",
     "Screensharing options" : "Opções de partilha de ecrã",
     "Enable screensharing" : "Ativar partilha de ecrã",
     "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
-    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
     "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
     "Download attendance list" : "Transferir lista de presenças",
     "Keep" : "Manter",
     "Select a region" : "Selecione uma região",
     "Submit" : "Submeter",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "User" : "Utilizador",
     "Password" : "Palavra-passe",
     "API token" : "Token de API",
@@ -383,6 +377,7 @@ OC.L10N.register(
     "Locations" : "Localizações",
     "Audio" : "Áudio",
     "Other" : "Outro",
+    "Default" : "Predefinida",
     "Group" : "Grupo",
     "Error while sharing file" : "Erro ao partilhar ficheiro",
     "Please reload the page." : "Por favor, recarregue a página.",
@@ -400,6 +395,11 @@ OC.L10N.register(
     "Tasks" : "Tarefas",
     "Notes" : "Notas",
     "Reports" : "Relatórios",
-    "Close" : "Fechar"
+    "Today" : "Hoje",
+    "Yesterday" : "Ontem",
+    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
+    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
+    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
