@@ -768,13 +768,6 @@ OC.L10N.register(
     "Invalid path selected" : "Percursu seletzionadu non bàlidu",
     "Upload" : "Càrriga",
     "Files" : "Archìvios",
-    "Message read by everyone who shares their reading status" : "Messàgiu lèghidu dae totu is persones chi cumpartzint s'istadu de letura issoro",
-    "Message sent" : "Messàgiu imbiadu",
-    "Deleting message" : "Cantzellende su messàgiu",
-    "Message deleted successfully" : "Messàgiu cantzelladu",
-    "Message could not be deleted because it is too old" : "Su messàgiu non si podet cantzellare ca est tropu betzu",
-    "Only normal chat messages can be deleted" : "Si podent cantzellare isceti is messàgios de tzarrada normales",
-    "An error occurred while deleting the message" : "B'at àpidu un'errore cantzellende su messàgiu",
     "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
     "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
     "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
@@ -793,6 +786,13 @@ OC.L10N.register(
     "The message has been forwarded to {selectedConversationName}" : "Messàgiu torradu a imbiare a {selectedConversationName}",
     "Dismiss" : "Iscarta",
     "Go to conversation" : "Bae a sa resonada",
+    "Message read by everyone who shares their reading status" : "Messàgiu lèghidu dae totu is persones chi cumpartzint s'istadu de letura issoro",
+    "Message sent" : "Messàgiu imbiadu",
+    "Deleting message" : "Cantzellende su messàgiu",
+    "Message deleted successfully" : "Messàgiu cantzelladu",
+    "Message could not be deleted because it is too old" : "Su messàgiu non si podet cantzellare ca est tropu betzu",
+    "Only normal chat messages can be deleted" : "Si podent cantzellare isceti is messàgios de tzarrada normales",
+    "An error occurred while deleting the message" : "B'at àpidu un'errore cantzellende su messàgiu",
     "Your browser does not support playing audio files" : "Su serbidore tuo non suportat sa riprodutzione de archìvios àudio",
     "Contact" : "Cuntata",
     "{stack} in {board}" : "{stack} in {board}",
@@ -1042,27 +1042,17 @@ OC.L10N.register(
     "__language_name__" : "sardu",
     "Tasks" : "Fainas",
     "Notes" : "Notas",
-    "You tried to call {user}" : "As proadu a tzerriare a {user}",
     "%s invited you to a conversation." : "%s t'at invitadu in una resonada",
     "You were invited to a conversation." : "T'ant invitadu in una resonada.",
     "Click the button below to join." : "Incarca su butone a suta pro intrare.",
     "Join »%s«" : "Intra in »%s«",
-    "{user} invited you to a private conversation" : "{user} t'at invitadu in una resonada privada",
-    "Copy conversation link" : "Còpia su ligòngiu de sa resonada",
     "Media settings" : "Cunfiguratzione de is elementos multimediales",
     "Today" : "Oe",
     "Yesterday" : "Eris",
     "_%n day ago_::_%n days ago_" : ["%n dies a oe","%n dies a oe"],
-    "Close" : "Serra",
     "Choose devices" : "Sèbera dispositivos",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk est istadu agiornadu, depes torrare a carrigare sa pàgina antis de pòdere cumintzare o intrare in una mutida.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Podes cumpartzire s'ischermu isceti cun Firefox versione 52 o prus noa.",
     "Screensharing extension is required to share your screen." : "Pro cumpartzire s'ischermu serbit un'estensione de Screensharing.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Imprea un'àteru navigadore comente Firefox o Chrome pro cumpartzire s'ischermu.",
-    "Nextcloud Talk was updated, please reload the page" : "Nextcloud est istadu agiornadu, torra a carrigare sa pàgina",
-    "An error happened when trying to share your file" : "B'at àpidu un'errore proende a cumpartzire s'archìviu",
-    "Failed to join the conversation. Try to reload the page." : "No at fatu a intrare in sa resonada. Proa a torrare a carrigare sa pàgina.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud est in mantenidura, torra a carrigare sa pàgina",
-    "Lost connection to signaling server. Try to reload the page manually." : "Connessione pèrdida cun su serbidore de signalatzione. Proa a torrare a carrigare sa pàgina a manu."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Imprea un'àteru navigadore comente Firefox o Chrome pro cumpartzire s'ischermu."
 },
 "nplurals=2; plural=(n != 1);");
