@@ -9,6 +9,7 @@ declare(strict_types=1);
 namespace OCA\Talk;
 
 use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Service\LiveTranscriptionService;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Services\IAppConfig;
 use OCP\Capabilities\IPublicCapability;
@@ -122,6 +123,7 @@ class Capabilities implements IPublicCapability {
 		'mutual-calendar-events',
 		'upcoming-reminders',
 		'sensitive-conversations',
+		'threads',
 	];
 
 	public const CONDITIONAL_FEATURES = [
@@ -207,6 +209,7 @@ class Capabilities implements IPublicCapability {
 		protected IAppManager $appManager,
 		protected ITranslationManager $translationManager,
 		protected ITaskProcessingManager $taskProcessingManager,
+		protected LiveTranscriptionService $liveTranscriptionService,
 		ICacheFactory $cacheFactory,
 	) {
 		$this->talkCache = $cacheFactory->createLocal('talk::');
@@ -217,6 +220,7 @@ class Capabilities implements IPublicCapability {
 	 *      spreed?: TalkCapabilities,
 	 * }
 	 */
+	#[\Override]
 	public function getCapabilities(): array {
 		$user = $this->userSession->getUser();
 		if ($user instanceof IUser && $this->talkConfig->isDisabledForUser($user)) {
@@ -247,6 +251,8 @@ class Capabilities implements IPublicCapability {
 					'max-duration' => $this->appConfig->getAppValueInt('max_call_duration'),
 					'blur-virtual-background' => $this->talkConfig->getBlurVirtualBackground($user?->getUID()),
 					'end-to-end-encryption' => $this->talkConfig->isCallEndToEndEncryptionEnabled(),
+					'live-transcription' => $this->talkConfig->getSignalingMode() === Config::SIGNALING_EXTERNAL
+						&& $this->liveTranscriptionService->isLiveTranscriptionAppEnabled(),
 				],
 				'chat' => [
 					'max-length' => ChatManager::MAX_CHAT_LENGTH,
@@ -346,11 +352,11 @@ class Capabilities implements IPublicCapability {
 			$capabilities['config']['call']['can-enable-sip'] = $this->talkConfig->canUserEnableSIP($user);
 		}
 
-		$supportedTaskTypes = $this->taskProcessingManager->getAvailableTaskTypes();
-		if (isset($supportedTaskTypes[TextToTextSummary::ID])) {
+		$supportedTaskTypeIds = $this->taskProcessingManager->getAvailableTaskTypeIds();
+		if (in_array(TextToTextSummary::ID, $supportedTaskTypeIds, true)) {
 			$capabilities['features'][] = 'chat-summary-api';
 		}
-		if (isset($supportedTaskTypes[TextToTextTranslate::ID])) {
+		if (in_array(TextToTextTranslate::ID, $supportedTaskTypeIds, true)) {
 			$capabilities['config']['chat']['has-translation-task-providers'] = true;
 		}
 
