@@ -101,6 +101,7 @@ class Notifier implements INotifier {
 	 * @return string
 	 * @since 17.0.0
 	 */
+	#[\Override]
 	public function getID(): string {
 		return 'talk';
 	}
@@ -111,6 +112,7 @@ class Notifier implements INotifier {
 	 * @return string
 	 * @since 17.0.0
 	 */
+	#[\Override]
 	public function getName(): string {
 		return $this->lFactory->get(Application::APP_ID)->t('Talk');
 	}
@@ -189,6 +191,7 @@ class Notifier implements INotifier {
 	 * @throws UnknownNotificationException
 	 * @since 9.0.0
 	 */
+	#[\Override]
 	public function prepare(INotification $notification, string $languageCode): INotification {
 		if ($notification->getApp() !== Application::APP_ID) {
 			throw new UnknownNotificationException('Incorrect app');
@@ -264,9 +267,9 @@ class Notifier implements INotifier {
 			return $this->parseInvitation($notification, $room, $l);
 		}
 		if ($subject === 'call') {
-			if ($participant instanceof Participant &&
-				$room->getLobbyState() !== Webinary::LOBBY_NONE &&
-				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+			if ($participant instanceof Participant
+				&& $room->getLobbyState() !== Webinary::LOBBY_NONE
+				&& !($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
 				// User is blocked by the lobby, remove notification
 				throw new AlreadyProcessedException();
 			}
@@ -277,9 +280,9 @@ class Notifier implements INotifier {
 			return $this->parseCall($notification, $room, $l);
 		}
 		if ($subject === 'reply' || $subject === 'mention' || $subject === 'mention_direct' || $subject === 'mention_group' || $subject === 'mention_team' || $subject === 'mention_all' || $subject === 'chat' || $subject === 'reaction' || $subject === 'reminder') {
-			if ($participant instanceof Participant &&
-				$room->getLobbyState() !== Webinary::LOBBY_NONE &&
-				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+			if ($participant instanceof Participant
+				&& $room->getLobbyState() !== Webinary::LOBBY_NONE
+				&& !($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
 				// User is blocked by the lobby, remove notification
 				throw new AlreadyProcessedException();
 			}
@@ -600,7 +603,14 @@ class Notifier implements INotifier {
 		];
 
 		// Set the link to the specific message
-		$notification->setLink($this->url->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()]) . '#message_' . $message->getMessageId());
+		$urlParams = [
+			'token' => $room->getToken(),
+			'_fragment' => 'message_' . $message->getMessageId(),
+		];
+		if (isset($messageParameters['threadId'])) {
+			$urlParams['threadId'] = $messageParameters['threadId'];
+		}
+		$notification->setLink($this->url->linkToRouteAbsolute('spreed.Page.showCall', $urlParams));
 
 		$now = $this->timeFactory->getDateTime();
 		$expireDate = $message->getExpirationDateTime();
@@ -629,6 +639,9 @@ class Notifier implements INotifier {
 
 			// Forward the message ID as well to the clients, so they can quote the message on replies
 			$notification->setObject($notification->getObjectType(), $notification->getObjectId() . '/' . $message->getMessageId());
+			if (isset($messageParameters['threadId'])) {
+				$notification->setObject($notification->getObjectType(), $notification->getObjectId() . '/' . $messageParameters['threadId']);
+			}
 		}
 
 		$richSubjectParameters = [
