@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native\ComplianceNode;
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\ErrorMessage;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\MessageBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\FloatType;
@@ -12,7 +14,6 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Utility\IsSingleton;
 
 use function assert;
 use function is_float;
-use function is_integer;
 use function is_numeric;
 
 /** @internal */
@@ -22,7 +23,12 @@ final class NativeFloatType implements FloatType
 
     public function accepts(mixed $value): bool
     {
-        return is_float($value) || is_integer($value);
+        return is_float($value);
+    }
+
+    public function compiledAccept(ComplianceNode $node): ComplianceNode
+    {
+        return Node::functionCall('is_float', [$node]);
     }
 
     public function matches(Type $other): bool
@@ -32,6 +38,7 @@ final class NativeFloatType implements FloatType
         }
 
         return $other instanceof self
+            || $other instanceof ScalarConcreteType
             || $other instanceof MixedType;
     }
 
@@ -52,6 +59,11 @@ final class NativeFloatType implements FloatType
         return MessageBuilder::newError('Value {source_value} is not a valid float.')->build();
     }
 
+    public function nativeType(): NativeFloatType
+    {
+        return $this;
+    }
+
     public function toString(): string
     {
         return 'float';
